@@ -398,6 +398,33 @@ func Test_ContainsAnySet(t *testing.T) {
 	}
 }
 
+func Test_ContainsAnyElement(t *testing.T) {
+	a := NewSet[int]()
+	a.Add(1)
+	a.Add(3)
+	a.Add(5)
+
+	b := NewSet[int]()
+	a.Add(2)
+	a.Add(4)
+	a.Add(6)
+
+	if ret := a.ContainsAnyElement(b); ret {
+		t.Errorf("set a not contain any element in set b")
+	}
+
+	a.Add(10)
+
+	if ret := a.ContainsAnyElement(b); ret {
+		t.Errorf("set a not contain any element in set b")
+	}
+
+	b.Add(10)
+
+	if ret := a.ContainsAnyElement(b); !ret {
+		t.Errorf("set a contain 10")
+	}
+}
 func Test_ClearSet(t *testing.T) {
 	a := makeSetInt([]int{2, 5, 9, 10})
 
@@ -1248,7 +1275,7 @@ func Test_EmptySetProperties(t *testing.T) {
 
 	c = a.Intersect(empty)
 	if !c.Equal(empty) {
-		t.Error("The intesection of any set with the empty set is supposed to be the empty set")
+		t.Error("The intersection of any set with the empty set is supposed to be the empty set")
 	}
 
 	if empty.Cardinality() != 0 {
@@ -1346,6 +1373,38 @@ func Test_NewThreadUnsafeSetFromMapKey_Strings(t *testing.T) {
 	}
 }
 
+func Test_Elements(t *testing.T) {
+	a := NewSet[string]()
+
+	a.Add("Z")
+	a.Add("Y")
+	a.Add("X")
+	a.Add("W")
+
+	b := NewSet[string]()
+	Elements(a)(func(elem string) bool {
+		b.Add(elem)
+		return true
+	})
+
+	if !a.Equal(b) {
+		t.Error("The sets are not equal after iterating (Each) through the first set")
+	}
+
+	var count int
+	Elements(a)(func(elem string) bool {
+		if count == 2 {
+			return false
+		}
+		count++
+		return true
+	})
+
+	if count != 2 {
+		t.Error("Iteration should stop on the way")
+	}
+}
+
 func Test_Example(t *testing.T) {
 	/*
 	   requiredClasses := NewSet()
